@@ -13,7 +13,7 @@ use Params::Util              ();
 use JSAN::Index::Distribution ();
 use JSAN::Index::Author       ();
 
-our $VERSION = '0.25';
+our $VERSION = '0.26';
 
 BEGIN {
     # Optional prefork.pm support
@@ -224,7 +224,7 @@ sub _archive {
     my $self = shift;
 
     # Load tarballs
-    if ( $self->source =~ /\.tar\.gz/ ) {
+    if ( $self->source =~ /\.tar\.gz$/ ) {
         require Archive::Tar;
         my $tar  = Archive::Tar->new;
         my $path = $self->mirror;
@@ -254,6 +254,16 @@ sub extract_libs {
     $self->extract_resource('lib', @_);
 }
 
+
+sub extract_static_files {
+    my $self = shift;
+    
+    my $static_dir = $self->meta_data->{static_dir} || 'static';
+    
+    $self->extract_resource($static_dir, @_, is_static => 1);
+}
+
+
 sub extract_tests {
     my $self = shift;
     $self->extract_resource('tests', @_);
@@ -262,7 +272,7 @@ sub extract_tests {
 sub extract_resource {
     my $self     = shift;
     my $resource = shift
-        or Carp::croak("No resource name provided to _extract_resource");
+        or Carp::croak("No resource name provided to extract_resource");
     my %params   = @_;
 
     # Check the extraction destination
@@ -308,8 +318,12 @@ sub _extract_resource_from_tar {
         shift @dirs;
 
         # Is this file in the resource directory
+        # Also skips all root-level files
         my $res = shift(@dirs) or next;
         next unless $res eq $resource;
+        
+        # Static files are put into the library, so /static/all.css becomes /Dist/Name/static/all.css
+        @dirs = (split(/\./, $self->distribution->name), $res, @dirs) if $params{is_static};
 
         # These are STILL relative, but we'll deal with that later.
         my $write_dir = File::Spec->catfile($params{to}, @dirs);
@@ -322,13 +336,16 @@ sub _extract_resource_from_tar {
     # Return the number of files, or error if none
     return $extracted_files if $extracted_files;
     my $path = $self->source;
-    Carp::croak("Tarball '$path' does not contain resource '$resource'");
+    
+    # Only resource 'static' is optional 
+    Carp::croak("Tarball '$path' does not contain resource '$resource'") unless $params{is_static};
 }
 
 sub _extract_resource_from_zip {
     Carp::croak("Zip support not yet completed");
 }
 
+
 sub _write {
     my ($self, $dir, $file, $content) = @_;
 
